@@ -1,7 +1,7 @@
 package File::Serialize;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: DWIM file serialization/deserialization
-$File::Serialize::VERSION = '1.0.1';
+$File::Serialize::VERSION = '1.1.0';
 use 5.16.0;
 
 use feature 'current_sub';
@@ -39,12 +39,13 @@ sub _generate_serialize_file {
         $options->{pretty} //= 1;
         $options->{canonical} //= 1;
 
-        $file = path($file) unless $file eq '-';
+        $file = path($file) unless $file eq '-' or ref $file eq 'SCALAR';
 
         my $serializer = _serializer($file, $options);
 
         $file = path( join '.', $file, $serializer->extension )
-            if $options->{add_extension} and $file ne '-';
+            if $options->{add_extension} and $file ne '-'
+                and ref $file ne 'SCALAR';
 
         my $method = $options->{utf8} ? 'spew_utf8' : 'spew';
 
@@ -52,7 +53,12 @@ sub _generate_serialize_file {
 
         return print $serialized if $file eq '-';
 
-        $file->$method($serialized);
+        if( ref $file eq 'SCALAR' ) {
+            $$file = $serialized;
+        }
+        else {
+            $file->$method($serialized);
+        }
     }
 }
 
@@ -62,7 +68,7 @@ sub _generate_deserialize_file {
     return sub {
         my( $file, $options ) = @_;
 
-        $file = path($file) unless $file eq '-';
+        $file = path($file) unless $file eq '-' or ref $file eq 'SCALAR';
 
         $options = { %$global, %{ $options||{} } } if $global;
         $options->{utf8} //= 1;
@@ -73,10 +79,12 @@ sub _generate_deserialize_file {
         my $serializer = _serializer($file, $options);
 
         $file = path( join '.', $file, $serializer->extension )
-            if $options->{add_extension} and $file ne '-';
+            if $options->{add_extension} and $file ne '-' and ref $file ne 'SCALAR';
 
         return $serializer->deserialize(
-            $file eq '-' ? do { local $/ = <STDIN> } : $file->$method, 
+            $file eq '-' ? do { local $/ = <STDIN> } 
+          : ref $file eq 'SCALAR' ? $$file
+          : $file->$method, 
             $options
         );
     }
@@ -132,7 +140,14 @@ sub _all_operative_formats {
 }
 
 sub _all_operative_serializers {
-    grep { $_->is_operative } sort __PACKAGE__->_all_serializers;
+    sort {
+        $b->precedence <=> $a->precedence
+            or
+        $a cmp $b
+    }
+    grep { $_->is_operative }
+    grep { $_->precedence }
+    __PACKAGE__->_all_serializers;
 }
 
 sub _serializer {
@@ -140,11 +155,12 @@ sub _serializer {
 
     no warnings qw/ uninitialized /;
 
-    my @serializers = __PACKAGE__->_all_operative_serializers;
+    my $serializers = $options->{serializers} || [ __PACKAGE__->_all_operative_serializers ];
+    s/^\+/File::Serialize::Serializer::/ for @$serializers;
 
     my $format = $options->{format} || ( $self->basename =~ /\.(\w+)$/ )[0];
 
-    return( first { $_->does_extension($format) } @serializers
+    return( first { $_->does_extension($format) } @$serializers
             or die "no serializer found for $format"
     );
 }
@@ -163,7 +179,7 @@ File::Serialize - DWIM file serialization/deserialization
 
 =head1 VERSION
 
-version 1.0.1
+version 1.1.0
 
 =head1 SYNOPSIS
 
@@ -196,75 +212,33 @@ an argument to the 'use' statement.
 
 =head1 SUPPORTED SERIALIZERS
 
-=head2 YAML
+File::Serialize will pick the serializer to use based on
+the extension of the filename or the explicitly given C<format>.
+If several serializers are registered for the format,
+the available serializer with the highest precedence number will
+be used.
 
 =over
 
-=item extensions
+=item YAML
 
-yaml, yml
+L<File::Serialize::Serialize::YAML::Tiny>
 
-=item module used
+=item JSON
 
-L<YAML::Tiny>
+L<File::Serialize::Serializer::JSON::MaybeXS>
 
-=item supported options
+=item TOML
 
-None
+L<File::Serialize::Serializer::TOML>
 
-=back
+=item XML
 
-=head2 JSON
+L<File::Serialize::Serializer::XML::Simple>
 
-=over
+=item jsony 
 
-=item extensions
-
-json, js
-
-=item module used
-
-L<JSON::MaybeXS>
-
-=item supported options
-
-pretty (default: true), canonical (default: true), allow_nonref (default: true)
-
-=back
-
-=head2 TOML
-
-=over
-
-=item extensions
-
-toml 
-
-=item module used
-
-L<TOML>
-
-=item supported options
-
-None
-
-=back
-
-=head2 XML
-
-=over
-
-=item extensions
-
-xml 
-
-=item module used
-
-L<XML::Simple>
-
-=item supported options
-
-None
+L<File::Serialize::Serializer::JSONY>
 
 =back
 
@@ -323,14 +297,23 @@ Defaults to C<true>.
     serialize_file '/path/to/file.json' => $data;
 
 If the C<$path> is 'C<->', the serialized data will be printed
-to STDOUT.
+to STDOUT. If it a scalar ref, the serialized data will be assigned
+to that variable.
+
+    serialize_file \my $serialized => $data;
+
+    print $serialized;
 
 =head2 deserialize_file $path, $options
 
     my $data = deserialize_file '/path/to/file.json';
 
 If the C<$path> is 'C<->', the serialized data will be read from
-STDIN.
+STDIN. If it a scalar ref, the serialized data will be read
+from that variable.
+
+    my $json = '{"foo":1}';
+    my $data = deserialize_file \$json;
 
 =head2 transerialize_file $input, @transformation_chain
 
