@@ -1,7 +1,7 @@
 package File::Serialize::Serializer;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: Role for defining File::Serialize serializers
-$File::Serialize::Serializer::VERSION = '1.0.1';
+$File::Serialize::Serializer::VERSION = '1.1.0';
 
 use strict;
 use warnings;
@@ -11,11 +11,14 @@ use Module::Info;
 use Module::Runtime qw/ use_module /;
 
 use Moo::Role;
+use MooX::ClassAttribute;
 
 requires 'extensions';  # first extension is the canonical one
 
 requires 'serialize', 'deserialize';
 
+sub precedence { 100 }
+
 sub required_modules {
     my $package = shift;
     $package =~ s/^File::Serialize::Serializer:://r;
@@ -80,7 +83,7 @@ File::Serialize::Serializer - Role for defining File::Serialize serializers
 
 =head1 VERSION
 
-version 1.0.1
+version 1.1.0
 
 =head1 SYNOPSIS
 
@@ -110,6 +113,8 @@ should be used to serialize/deserialize a specific file, it's important that
 the modules on which the serializer depends are not just C<use>d, but are rather
 marked for import via the C<required_modules> and C<init> functions.
 
+=head2 Required methods
+
 A serializer should implement the following class methods:
 
 =over
@@ -154,6 +159,19 @@ provided, C<groom_options> is used.
 
 =back
 
+=head2 Provided methods
+
+The role provides the following attributes / methods:
+
+=over
+
+=item precedence 
+
+Returns the serializer's precedence, used to determine which one of the available
+serializer for a format to use. Default to C<100>. A value of C<0> means "don't use".
+
+=back
+
 =head1 AUTHOR
 
 Yanick Champoux <yanick@cpan.org>
