@@ -1,6 +1,7 @@
 package File::Serialize::Serializer::JSON::MaybeXS;
 our $AUTHORITY = 'cpan:YANICK';
-$File::Serialize::Serializer::JSON::MaybeXS::VERSION = '1.0.1';
+#ABSTRACT: JSON::MaybeXS serializer for File::Serialize
+$File::Serialize::Serializer::JSON::MaybeXS::VERSION = '1.1.0';
 use strict;
 use warnings;
 
@@ -40,11 +41,33 @@ __END__
 
 =head1 NAME
 
-File::Serialize::Serializer::JSON::MaybeXS
+File::Serialize::Serializer::JSON::MaybeXS - JSON::MaybeXS serializer for File::Serialize
 
 =head1 VERSION
 
-version 1.0.1
+version 1.1.0
+
+=head1 DESCRIPTION
+
+=over
+
+=item B<extensions>
+
+C<json>, C<js>.
+
+=item B<precedence>
+
+100
+
+=item B<module used>
+
+L<JSON::MaybeXS>
+
+=item B<supported options>
+
+pretty (default: true), canonical (default: true), allow_nonref (default: true)
+
+=back
 
 =head1 AUTHOR
 
