@@ -1,6 +1,7 @@
 package File::Serialize::Serializer::TOML;
 our $AUTHORITY = 'cpan:YANICK';
-$File::Serialize::Serializer::TOML::VERSION = '1.0.1';
+#ABSTRACT: TOML serializer for File::Serialize
+$File::Serialize::Serializer::TOML::VERSION = '1.1.0';
 use strict;
 use warnings;
 
@@ -22,9 +23,6 @@ sub deserialize {
 
 1;
 
-
-use warnings;
-
 __END__
 
 =pod
@@ -33,11 +31,33 @@ __END__
 
 =head1 NAME
 
-File::Serialize::Serializer::TOML
+File::Serialize::Serializer::TOML - TOML serializer for File::Serialize
 
 =head1 VERSION
 
-version 1.0.1
+version 1.1.0
+
+=head1 DESCRIPTION
+
+=over
+
+=item B<extensions>
+
+C<toml>
+
+=item B<precedence>
+
+100
+
+=item B<module used>
+
+L<TOML>
+
+=item B<supported options>
+
+None
+
+=back
 
 =head1 AUTHOR
 
