@@ -1,6 +1,7 @@
 package File::Serialize::Serializer::YAML::Tiny;
 our $AUTHORITY = 'cpan:YANICK';
-$File::Serialize::Serializer::YAML::Tiny::VERSION = '1.0.1';
+#ABSTRACT: YAML::Tiny serializer for File::Serialize
+$File::Serialize::Serializer::YAML::Tiny::VERSION = '1.1.0';
 use strict;
 use warnings;
 
@@ -30,11 +31,33 @@ __END__
 
 =head1 NAME
 
-File::Serialize::Serializer::YAML::Tiny
+File::Serialize::Serializer::YAML::Tiny - YAML::Tiny serializer for File::Serialize
 
 =head1 VERSION
 
-version 1.0.1
+version 1.1.0
+
+=head1 DESCRIPTION
+
+=over
+
+=item B<extensions>
+
+C<yaml>, C<yml>.
+
+=item B<precedence>
+
+100
+
+=item B<module used>
+
+L<YAML::Tiny>
+
+=item B<supported options>
+
+none
+
+=back
 
 =head1 AUTHOR
 
